==> lxqt-l10n_0.10.9.orig.tar.xz: lxqt-l10n-0.10.9/lxqt-admin/lxqt-admin-user/lxqt-admin-user_hu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>GroupDialog</name>
    <message>
        <location filename="../groupdialog.ui" line="14"/>
        <source>Group Settings</source>
        <translation>Csoportbeállítás</translation>
    </message>
    <message>
        <location filename="../groupdialog.ui" line="20"/>
        <source>Group name:</source>
        <translation>Csoportnév:</translation>
    </message>
    <message>
        <location filename="../groupdialog.ui" line="37"/>
        <source>Group ID:</source>
        <translation>Csoport ID:</translation>
    </message>
    <message>
        <location filename="../groupdialog.ui" line="44"/>
        <source>Users belong to this group:</source>
        <translation>A csoport tagjai:</translation>
    </message>
    <message>
        <location filename="../groupdialog.cpp" line="83"/>
        <location filename="../groupdialog.cpp" line="92"/>
        <location filename="../groupdialog.cpp" line="97"/>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <location filename="../groupdialog.cpp" line="83"/>
        <source>The group ID is in use.</source>
        <translation>Csoport ID foglalt.</translation>
    </message>
    <message>
        <location filename="../groupdialog.cpp" line="92"/>
        <source>The group name cannot be empty.</source>
        <translation>Csoportnév nem lehet üres.</translation>
    </message>
    <message>
        <location filename="../groupdialog.cpp" line="97"/>
        <source>The group name is in use.</source>
        <translation>Csoportnév foglalt.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>User and Group Settings</source>
        <translation>Felhasználók és csoportok</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="31"/>
        <source>&amp;Users</source>
        <translation>&amp;Felhasználók</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="50"/>
        <source>Login Name</source>
        <translation>Bejelenkezési név</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="55"/>
        <source>User ID</source>
        <translation>Felhasználó ID</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="60"/>
        <source>Full Name</source>
        <translation>Teljes név</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="65"/>
        <source>Group</source>
        <translation>Csoport</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="70"/>
        <source>Home Directory</source>
        <translation>Saját könyvtár</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="81"/>
        <source>Show system users (for advanced users only)</source>
        <translation>Rendszer felhasználók is látszanak (csak haladóknak)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="89"/>
        <source>&amp;Groups</source>
        <translation>&amp;Csoportok</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="102"/>
        <source>Name</source>
        <translation>Név</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="107"/>
        <source>Group ID</source>
        <translation>Csoport ID</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="120"/>
        <source>toolBar</source>
        <translation>eszközsáv</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="147"/>
        <source>Add</source>
        <translation>Hozzáad</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="150"/>
        <source>Add new users or groups</source>
        <translation>Új felhasználó, vagy csoport hozzáadása</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="160"/>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="163"/>
        <source>Delete selected item</source>
        <translation>Kiválasztott törlése</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="173"/>
        <source>Properties</source>
        <translation>Tulajdonságok</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="176"/>
        <source>edit properties of the selected item</source>
        <translation>A választott elem módosítása</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="186"/>
        <source>Refresh</source>
        <translation>Frisítés</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="189"/>
        <source>Refresh the lists</source>
        <translation>Lista frissítése</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="145"/>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="191"/>
        <location filename="../mainwindow.cpp" line="204"/>
        <source>Confirm</source>
        <translation>Megerősítés</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="191"/>
        <source>Are you sure you want to delete the selected user?</source>
        <translation>Tényleg töröljük az illető felhasználót?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="204"/>
        <source>Are you sure you want to delete the selected group?</source>
        <translation>Tényleg töröljük az illető csoportot?</translation>
    </message>
</context>
<context>
    <name>UserDialog</name>
    <message>
        <location filename="../userdialog.ui" line="14"/>
        <source>User Settings</source>
        <translation>Felhasználó beállítása</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="24"/>
        <source>General</source>
        <translation>Alap</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="33"/>
        <source>Full name:</source>
        <translation>Teljes név:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="43"/>
        <source>Login name:</source>
        <translation>Bejelenkezési név:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="53"/>
        <source>Set password:</source>
        <translation>Jelszóbeállítás:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="77"/>
        <source>User ID:</source>
        <translation>Felhasználó ID:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="84"/>
        <source>Main group:</source>
        <translation>Főcsoport:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="99"/>
        <source>Advanced</source>
        <translation>Bővített</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="105"/>
        <source>Login shell:</source>
        <translation>Parancsértelmező:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="122"/>
        <source>Home directory:</source>
        <translation>Saját könyvtár:</translation>
    </message>
    <message>
        <location filename="../userdialog.cpp" line="64"/>
        <source>Change password:</source>
        <translation>Jelszóváltoztatás:</translation>
    </message>
    <message>
        <location filename="../userdialog.cpp" line="125"/>
        <location filename="../userdialog.cpp" line="138"/>
        <location filename="../userdialog.cpp" line="143"/>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <location filename="../userdialog.cpp" line="125"/>
        <source>The user ID is in use.</source>
        <translation>Felhasználó ID foglalt.</translation>
    </message>
    <message>
        <location filename="../userdialog.cpp" line="138"/>
        <source>The user name cannot be empty.</source>
        <translation>Felhasználónév nem lehet üres.</translation>
    </message>
    <message>
        <location filename="../userdialog.cpp" line="143"/>
        <source>The user name is in use.</source>
        <translation>Felhasználónév foglalt.</translation>
    </message>
    <message>
        <location filename="../userdialog.cpp" line="159"/>
        <source>Confirm</source>
        <translation>Megerősítés</translation>
    </message>
    <message>
        <location filename="../userdialog.cpp" line="159"/>
        <source>Are you sure you want to use an &quot;empty password&quot; for the user?</source>
        <translation>Üres legyen a jelszava a felhasználónak?</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-admin/lxqt-admin-user/lxqt-admin-user_hu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>GroupDialog</name>
    <message>
        <location filename="../../../groupdialog.ui" line="14"/>
        <source>Group Settings</source>
        <translation>Csoportbeállítás</translation>
    </message>
    <message>
        <location filename="../../../groupdialog.ui" line="20"/>
        <source>Group name:</source>
        <translation>Csoportnév:</translation>
    </message>
    <message>
        <location filename="../../../groupdialog.ui" line="37"/>
        <source>Group ID:</source>
        <translation>Csoport ID:</translation>
    </message>
    <message>
        <location filename="../../../groupdialog.ui" line="44"/>
        <source>Users belong to this group:</source>
        <translation>A csoport tagjai:</translation>
    </message>
    <message>
        <location filename="../../../groupdialog.cpp" line="86"/>
        <location filename="../../../groupdialog.cpp" line="95"/>
        <location filename="../../../groupdialog.cpp" line="100"/>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <location filename="../../../groupdialog.cpp" line="86"/>
        <source>The group ID is in use.</source>
        <translation>Csoport ID foglalt.</translation>
    </message>
    <message>
        <location filename="../../../groupdialog.cpp" line="95"/>
        <source>The group name cannot be empty.</source>
        <translation>Csoportnév nem lehet üres.</translation>
    </message>
    <message>
        <location filename="../../../groupdialog.cpp" line="100"/>
        <source>The group name is in use.</source>
        <translation>Csoportnév foglalt.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../../mainwindow.ui" line="14"/>
        <source>User and Group Settings</source>
        <translation>Felhasználók és csoportok</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="31"/>
        <source>&amp;Users</source>
        <translation>&amp;Felhasználók</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="50"/>
        <source>Login Name</source>
        <translation>Bejelenkezési név</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="55"/>
        <source>User ID</source>
        <translation>Felhasználó ID</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="60"/>
        <source>Full Name</source>
        <translation>Teljes név</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="65"/>
        <source>Group</source>
        <translation>Csoport</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="70"/>
        <source>Home Directory</source>
        <translation>Saját könyvtár</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="81"/>
        <source>Show system users (for advanced users only)</source>
        <translation>Rendszer felhasználók is látszanak (csak haladóknak)</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="89"/>
        <source>&amp;Groups</source>
        <translation>&amp;Csoportok</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="102"/>
        <source>Name</source>
        <translation>Név</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="107"/>
        <source>Group ID</source>
        <translation>Csoport ID</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="120"/>
        <source>toolBar</source>
        <translation>eszközsáv</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="147"/>
        <source>Add</source>
        <translation>Hozzáad</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="150"/>
        <source>Add new users or groups</source>
        <translation>Új felhasználó, vagy csoport hozzáadása</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="160"/>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="163"/>
        <source>Delete selected item</source>
        <translation>Kiválasztott törlése</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="173"/>
        <source>Properties</source>
        <translation>Tulajdonságok</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="176"/>
        <source>edit properties of the selected item</source>
        <translation>A választott elem módosítása</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="186"/>
        <source>Refresh</source>
        <translation>Frisítés</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="189"/>
        <source>Refresh the lists</source>
        <translation>Lista frissítése</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="145"/>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="191"/>
        <location filename="../../../mainwindow.cpp" line="204"/>
        <source>Confirm</source>
        <translation>Megerősítés</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="191"/>
        <source>Are you sure you want to delete the selected user?</source>
        <translation>Tényleg töröljük az illető felhasználót?</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="204"/>
        <source>Are you sure you want to delete the selected group?</source>
        <translation>Tényleg töröljük az illető csoportot?</translation>
    </message>
</context>
<context>
    <name>UserDialog</name>
    <message>
        <location filename="../../../userdialog.ui" line="14"/>
        <source>User Settings</source>
        <translation>Felhasználó beállítása</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="24"/>
        <source>General</source>
        <translation>Alap</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="33"/>
        <source>Full name:</source>
        <translation>Teljes név:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="43"/>
        <source>Login name:</source>
        <translation>Bejelenkezési név:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="53"/>
        <source>Set password:</source>
        <translation>Jelszóbeállítás:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="77"/>
        <source>User ID:</source>
        <translation>Felhasználó ID:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="84"/>
        <source>Main group:</source>
        <translation>Főcsoport:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="99"/>
        <source>Advanced</source>
        <translation>Bővített</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="105"/>
        <source>Login shell:</source>
        <translation>Parancsértelmező:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="122"/>
        <source>Home directory:</source>
        <translation>Saját könyvtár:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.cpp" line="67"/>
        <source>Change password:</source>
        <translation>Jelszóváltoztatás:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.cpp" line="128"/>
        <location filename="../../../userdialog.cpp" line="141"/>
        <location filename="../../../userdialog.cpp" line="146"/>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <location filename="../../../userdialog.cpp" line="128"/>
        <source>The user ID is in use.</source>
        <translation>Felhasználó ID foglalt.</translation>
    </message>
    <message>
        <location filename="../../../userdialog.cpp" line="141"/>
        <source>The user name cannot be empty.</source>
        <translation>Felhasználónév nem lehet üres.</translation>
    </message>
    <message>
        <location filename="../../../userdialog.cpp" line="146"/>
        <source>The user name is in use.</source>
        <translation>Felhasználónév foglalt.</translation>
    </message>
    <message>
        <location filename="../../../userdialog.cpp" line="162"/>
        <source>Confirm</source>
        <translation>Megerősítés</translation>
    </message>
    <message>
        <location filename="../../../userdialog.cpp" line="162"/>
        <source>Are you sure you want to use an &quot;empty password&quot; for the user?</source>
        <translation>Üres legyen a jelszava a felhasználónak?</translation>
    </message>
</context>
</TS>
